

//信用信息 委三清单信息管理查询
import {requestInstance} from "@/service";

//数据清单 事项类别
export function proSelectUnitNewSjqdSXLB(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewSjqdSXLB',
        data:{
        }
    })
}

//数据清单 编制部门
export function proSelectUnitNewSjqdBZBM(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewSjqdBZBM',
        data:{
        }
    })
}

//数据清单 年度
export function proSelectUnitNewSjqdBBH(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewSjqdBBH',
        data:{
        }
    })
}



//行为清单 事项类别
export function proSelectUnitNewXwqdCDFJ(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewXwqdCDFJ',
        data:{
        }
    })
}

//行为清单 编制部门
export function proSelectUnitNewXwqdBMMC(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewXwqdBMMC',
        data:{
        }
    })
}

//行为清单 年度
export function proSelectUnitNewXwqdBBH(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewXwqdBBH',
        data:{
        }
    })
}



//应用清单 事项类别
export function proSelectUnitNewYyqdSXLB(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewYyqdSXLB',
        data:{
        }
    })
}

//行为清单 编制部门
export function proSelectUnitNewYyqdBMMC(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewYyqdBMMC',
        data:{
        }
    })
}

//行为清单 年度
export function proSelectUnitNewYyqdBBH(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewYyqdBBH',
        data:{
        }
    })
}


//本部门奖惩清单 事项类别
export function proSelectUnitNewBbmjccsYYSX(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewBbmjccsYYSX',
        data:{
        }
    })
}

//本部门奖惩清单 编制部门
export function proSelectUnitNewBbmjccsBMMC(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewBbmjccsBMMC',
        data:{
        }
    })
}

//本部门奖惩清单 年度
export function proSelectUnitNewBbmjccsBBH(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewBbmjccsBBH',
        data:{
        }
    })
}

//其他部门奖惩清单 制度依据
export function proSelectUnitNewQtbmjccsZDYJ(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewQtbmjccsZDYJ',
        data:{
        }
    })
}

//其他部门奖惩清单 编制部门
export function proSelectUnitNewQtbmjccsBMMC(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewQtbmjccsBMMC',
        data:{
        }
    })
}

//其他部门奖惩清单 年度
export function proSelectUnitNewQtbmjccsBBH(){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitNewQtbmjccsBBH',
        data:{
        }
    })
}

//所有清单 首页查询
export function proSelectXyxxSqd(params){
    return requestInstance({
        url:'/XyxxApi/proSelectXyxxSqd',
        data:{
            ...params
        }
    })
}

//所有清单  新增
export function proInsertXyxxSqd(params){
    debugger
    return requestInstance({
        url:'/XyxxApi/proInsertXyxxSqd',
        data:{
            ...params
        }
    })
}

//所有清单  修改
export function proUpdateXyxxSqd(params){
    return requestInstance({
        url:'/XyxxApi/proUpdateXyxxSqd',
        data:{
            ...params
        }
    })
}

//所有清单  删除
export function proDeleteXyxxSqd(params){
    return requestInstance({
        url:'/XyxxApi/proDeleteXyxxSqd',
        data:{
            ...params
        }
    })
}




